searchData={"items":[{"type":"module","title":"ActiveMQClient","doc":"Generic ActiveMQ client using STOMP protocol for Artemis ActiveMQ.\n\nThis library provides a high-level interface for connecting to and interacting with\nApache ActiveMQ Artemis using the STOMP protocol. It handles message publishing, \nconsuming, and subscription management with configurable message filtering.","ref":"ActiveMQClient.html"},{"type":"module","title":"Features - ActiveMQClient","doc":"- STOMP-based connection to Artemis ActiveMQ\n- Message publishing and consuming\n- Topic and queue subscription management\n- Configurable message filtering with selectors\n- Automatic reconnection and error handling\n- Callback-based message processing","ref":"ActiveMQClient.html#module-features"},{"type":"module","title":"Usage - ActiveMQClient","doc":"# Start the client\n    {:ok, _} = ActiveMQClient.start_link([\n      host: \"localhost\", \n      port: 61613,\n      username: \"artemis\",\n      password: \"artemis\",\n      message_handler: &MyApp.handle_message/1\n    ])\n    \n    # Publish a message\n    ActiveMQClient.publish_message(\"Hello World!\", \"/queue/test\")\n    \n    # Subscribe to a queue\n    ActiveMQClient.subscribe_to_queue(\"/queue/test\")\n    \n    # Subscribe to topic with message filter\n    ActiveMQClient.subscribe_to_topic_with_selector(\n      \"/topic/events\", \n      \"type = 'MY_EVENT'\", \n      \"my_subscription\"\n    )","ref":"ActiveMQClient.html#module-usage"},{"type":"function","title":"ActiveMQClient.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ActiveMQClient.html#child_spec/1"},{"type":"function","title":"ActiveMQClient.get_status/0","doc":"Gets the current client status.","ref":"ActiveMQClient.html#get_status/0"},{"type":"function","title":"Returns - ActiveMQClient.get_status/0","doc":"Map containing connection status, host, port, subscriptions, etc.","ref":"ActiveMQClient.html#get_status/0-returns"},{"type":"function","title":"ActiveMQClient.publish_message/2","doc":"Publishes a message to a destination.","ref":"ActiveMQClient.html#publish_message/2"},{"type":"function","title":"Parameters - ActiveMQClient.publish_message/2","doc":"- `message` - Message content as string\n- `destination` - Destination queue or topic (optional, uses default if nil)","ref":"ActiveMQClient.html#publish_message/2-parameters"},{"type":"function","title":"Returns - ActiveMQClient.publish_message/2","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"ActiveMQClient.html#publish_message/2-returns"},{"type":"function","title":"ActiveMQClient.reconnect/0","doc":"Triggers a manual reconnection attempt.","ref":"ActiveMQClient.html#reconnect/0"},{"type":"function","title":"ActiveMQClient.send_reply/3","doc":"Sends a reply message to a destination with message type.","ref":"ActiveMQClient.html#send_reply/3"},{"type":"function","title":"Parameters - ActiveMQClient.send_reply/3","doc":"- `reply_json` - JSON reply content\n- `reply_destination` - Destination to send reply to\n- `message_type` - Message type header","ref":"ActiveMQClient.html#send_reply/3-parameters"},{"type":"function","title":"Returns - ActiveMQClient.send_reply/3","doc":"- `:ok` on success","ref":"ActiveMQClient.html#send_reply/3-returns"},{"type":"function","title":"ActiveMQClient.set_message_handler/1","doc":"Sets a custom message handler function.","ref":"ActiveMQClient.html#set_message_handler/1"},{"type":"function","title":"Parameters - ActiveMQClient.set_message_handler/1","doc":"- `handler` - Function to handle incoming messages","ref":"ActiveMQClient.html#set_message_handler/1-parameters"},{"type":"function","title":"ActiveMQClient.start_link/1","doc":"Starts the ActiveMQ client process.","ref":"ActiveMQClient.html#start_link/1"},{"type":"function","title":"Options - ActiveMQClient.start_link/1","doc":"- `:host` - ActiveMQ server hostname (default: \"localhost\")\n- `:port` - ActiveMQ STOMP port (default: 61613) \n- `:username` - Authentication username (default: \"artemis\")\n- `:password` - Authentication password (default: \"artemis\")\n- `:queue` - Default queue destination (default: \"/queue/artemis_queue\")\n- `:topic` - Default topic destination (default: \"/topic/artemis_topic\")\n- `:message_handler` - Custom message handler function","ref":"ActiveMQClient.html#start_link/1-options"},{"type":"function","title":"ActiveMQClient.subscribe_multiple/1","doc":"Subscribes to multiple topics/queues with different selectors.","ref":"ActiveMQClient.html#subscribe_multiple/1"},{"type":"function","title":"Parameters - ActiveMQClient.subscribe_multiple/1","doc":"- `subscriptions` - List of {destination, selector, subscription_id} tuples","ref":"ActiveMQClient.html#subscribe_multiple/1-parameters"},{"type":"function","title":"Returns - ActiveMQClient.subscribe_multiple/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"ActiveMQClient.html#subscribe_multiple/1-returns"},{"type":"function","title":"ActiveMQClient.subscribe_to_queue/1","doc":"Subscribes to a queue destination.","ref":"ActiveMQClient.html#subscribe_to_queue/1"},{"type":"function","title":"Parameters - ActiveMQClient.subscribe_to_queue/1","doc":"- `queue` - Queue destination (optional, uses default if nil)","ref":"ActiveMQClient.html#subscribe_to_queue/1-parameters"},{"type":"function","title":"Returns - ActiveMQClient.subscribe_to_queue/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"ActiveMQClient.html#subscribe_to_queue/1-returns"},{"type":"function","title":"ActiveMQClient.subscribe_to_topic/1","doc":"Subscribes to a topic destination.","ref":"ActiveMQClient.html#subscribe_to_topic/1"},{"type":"function","title":"Parameters - ActiveMQClient.subscribe_to_topic/1","doc":"- `topic` - Topic destination (optional, uses default if nil)","ref":"ActiveMQClient.html#subscribe_to_topic/1-parameters"},{"type":"function","title":"Returns - ActiveMQClient.subscribe_to_topic/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"ActiveMQClient.html#subscribe_to_topic/1-returns"},{"type":"function","title":"ActiveMQClient.subscribe_to_topic_with_selector/3","doc":"Subscribes to a topic with a message selector.","ref":"ActiveMQClient.html#subscribe_to_topic_with_selector/3"},{"type":"function","title":"Parameters - ActiveMQClient.subscribe_to_topic_with_selector/3","doc":"- `topic` - Topic destination\n- `selector` - Message selector for filtering\n- `subscription_id` - Unique subscription identifier","ref":"ActiveMQClient.html#subscribe_to_topic_with_selector/3-parameters"},{"type":"function","title":"Returns - ActiveMQClient.subscribe_to_topic_with_selector/3","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"ActiveMQClient.html#subscribe_to_topic_with_selector/3-returns"},{"type":"function","title":"ActiveMQClient.unsubscribe/1","doc":"Unsubscribes from a destination.","ref":"ActiveMQClient.html#unsubscribe/1"},{"type":"function","title":"Parameters - ActiveMQClient.unsubscribe/1","doc":"- `destination` - Destination to unsubscribe from","ref":"ActiveMQClient.html#unsubscribe/1-parameters"},{"type":"function","title":"Returns - ActiveMQClient.unsubscribe/1","doc":"- `:ok` on success\n- `{:error, reason}` on failure","ref":"ActiveMQClient.html#unsubscribe/1-returns"},{"type":"extras","title":"ActiveMQ Client","doc":"# ActiveMQ Client\n\nActiveMQ client library for Artemis ActiveMQ using STOMP protocol connection.\n\nThis library provides a high-level interface for connecting to and interacting with Apache ActiveMQ Artemis using the STOMP protocol. It handles message publishing, consuming, subscription management, and job scheduling/cancellation.","ref":"readme.html"},{"type":"extras","title":"Features - ActiveMQ Client","doc":"- **STOMP-based connection** to Artemis ActiveMQ\n- **Message publishing and consuming** with automatic reconnection\n- **Topic and queue subscription management** with selectors\n- **Job scheduling and cancellation** with reply handling\n- **Callback-based message processing** for flexible integration\n- **Automatic error handling** and connection recovery","ref":"readme.html#features"},{"type":"extras","title":"Installation - ActiveMQ Client","doc":"Add `activemq_client` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:activemq_client, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - ActiveMQ Client","doc":"```elixir\n# Start the client\n{:ok, _} = ActiveMQClient.start_link([\n  host: \"localhost\", \n  port: 61613,\n  username: \"artemis\",\n  password: \"artemis\"\n])\n\n# Publish a message\nActiveMQClient.publish_message(\"Hello World!\", \"/queue/test\")\n\n# Subscribe to a queue\nActiveMQClient.subscribe_to_queue(\"/queue/test\")\n\n# Start listening for job commands\nActiveMQClient.start_listening()\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Configuration - ActiveMQ Client","doc":"The client can be configured with the following options:\n\n- `:host` - ActiveMQ server hostname (default: \"localhost\")\n- `:port` - ActiveMQ STOMP port (default: 61613) \n- `:username` - Authentication username (default: \"artemis\")\n- `:password` - Authentication password (default: \"artemis\")\n- `:queue` - Default queue destination (default: \"/queue/artemis_queue\")\n- `:topic` - Default topic destination (default: \"/topic/artemis_topic\")\n- `:message_handler` - Custom message handler function","ref":"readme.html#configuration"},{"type":"extras","title":"Job Handling - ActiveMQ Client","doc":"The library supports job scheduling and cancellation through STOMP message selectors:\n\n```elixir\n# Start listening for SCHEDULE_JOB_COMMAND and CANCEL_JOB_COMMAND messages\nActiveMQClient.start_listening()\n```\n\nJob commands are automatically processed and integrated with the timer system's database and scheduler.","ref":"readme.html#job-handling"},{"type":"extras","title":"Dependencies - ActiveMQ Client","doc":"This library depends only on:\n- `stomp_client` - Custom STOMP protocol implementation\n- `jason` - JSON encoding/decoding","ref":"readme.html#dependencies"},{"type":"extras","title":"Documentation - ActiveMQ Client","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"License - ActiveMQ Client","doc":"MIT License","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}